@@ -1,3 +1,5 @@
+pub use crate::user::User;
 pub use crate::Client;
 pub use crate::EventHandler;
+pub use anyhow::Result;
 pub use async_trait::async_trait;
